Examples
========

Page objects
------------

google search
~~~~~~~~~~~~~
.. literalinclude:: ../../examples/google/pages.py 

wikipedia 
~~~~~~~~~
.. literalinclude:: ../../examples/wikipedia/pages.py


Test cases  driven by nosetests 
-------------------------------
Google plain text search example
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. literalinclude:: ../../examples/google/test_search_text.py 

Wikipedia text search example using all featured languages on wikipedia homepage
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. literalinclude:: ../../examples/wikipedia/test_search_article.py

